crystal_toolkit.helpers.povray_renderer module — Crystal Toolkit documentation

# crystal_toolkit.helpers.povray_renderer module

Export wrapper for POV-Ray For creating publication quality plots

crystal_toolkit.helpers.povray_renderer.filter_data(scene_data, fstream)

  Recursively traverse the scene_data dictionary to find objects to draw

crystal_toolkit.helpers.povray_renderer.get_render_settings(file_name)

  Creates a POV-Ray render.ini file

crystal_toolkit.helpers.povray_renderer.pov_write_data(input_scene_comp, fstream)

  parse a primitive display object in crystaltoolkit and print it to POV-Ray input_scene_comp fstream

crystal_toolkit.helpers.povray_renderer.write_pov_file(smc, file_name)

  smc : (StructureMoleculeComponent)